import path from 'path'
import yargs from 'yargs'
import fs from 'fs'
import { hideBin } from 'yargs/helpers'
import * as hogan from 'hogan.js'
import defaultTemplate from './defaultTemplate'
const argv = yargs(hideBin(process.argv)).argv

const pkgPath = path.resolve(process.cwd(), 'package.json')
let pkg: { [key: string]: unknown }
try {
    pkg = JSON.parse(fs.readFileSync(pkgPath).toString())
} catch (e) {
    throw new Error(`Unable to parse ${pkgPath}: ${e.message}`)
}

Object.keys(pkg).forEach(k => {
    if ('dependencies' === k) {
        pkg.dependencies = Object.keys(pkg.dependencies).map((key) => {
            const depPkgPath = path.resolve(process.cwd(), 'node_modules', key, 'package.json')
            return JSON.parse(fs.readFileSync(depPkgPath).toString())
        })
    }

    if ('devDependencies' === k) {
        pkg.devDependencies = Object.keys(pkg.devDependencies).map((key) => {
            const depPkgPath = path.resolve(process.cwd(), 'node_modules', key, 'package.json')
            return JSON.parse(fs.readFileSync(depPkgPath).toString())
        })
    }
})



const template = argv['template'] || defaultTemplate

const out = hogan.compile(template).render(pkg)

fs.writeFileSync(path.resolve(process.cwd(), 'README.md'), out)
